@@ -53,7 +53,7 @@ public class Textifier extends Printer {
   /** The help message shown when command line arguments are incorrect. */
   private static final String USAGE =
       "Prints a disassembled view of the given class.\n"
-          + "Usage: Textifier [-debug] <fully qualified class name or class file name>";
+          + "Usage: Textifier [-nodebug] <fully qualified class name or class file name>";
 
   /** The type of internal names. See {@link #appendDescriptor}. */
   public static final int INTERNAL_NAME = 0;
@@ -132,7 +132,7 @@ public class Textifier extends Printer {
   /**
    * Prints a disassembled view of the given class to the standard output.
    *
-   * <p>Usage: Textifier [-debug] &lt;binary class name or class file name &gt;
+   * <p>Usage: Textifier [-nodebug] &lt;binary class name or class file name &gt;
    *
    * @param args the command line arguments.
    * @throws IOException if the class cannot be found, or if an IOException occurs.
@@ -144,7 +144,7 @@ public class Textifier extends Printer {
   /**
    * Prints a disassembled view of the given class to the given output.
    *
-   * <p>Usage: Textifier [-debug] &lt;binary class name or class file name &gt;
+   * <p>Usage: Textifier [-nodebug] &lt;binary class name or class file name &gt;
    *
    * @param args the command line arguments.
    * @param output where to print the result.
